/*!
   Copyright 2019 Ron Buckton

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
import { AsyncLockable, LockHandle } from "@esfx/async-lockable";
import { Cancelable } from "@esfx/cancelable";
/**
 * An async coordination primitive used to coordinate access to a protected resource.
 */
export declare class AsyncMutex implements AsyncLockable {
    private _waiters;
    private _handle;
    [Symbol.toStringTag]: string;
    /**
     * Indicates whether the lock has been taken.
     */
    get isLocked(): boolean;
    /**
     * Asynchronously waits for the lock to become available and then takes the lock.
     * @param cancelable A `Cancelable` used to cancel the pending request.
     */
    lock(cancelable?: Cancelable): Promise<LockHandle<AsyncMutex>>;
    /**
     * Synchronously tries to take a lock.
     */
    tryLock(): boolean;
    /**
     * Releases the lock.
     */
    unlock(): boolean;
    private _lock;
    private _unlock;
    [AsyncLockable.lock](cancelable?: Cancelable): Promise<LockHandle<AsyncMutex>>;
    [AsyncLockable.unlock](): void;
}
//# sourceMappingURL=index.d.ts.map